==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fa.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "ذخیره شده ",
    "Saving failed:" : "ذخیره فایل با خطا مواجه شد.",
    "File MIME type" : "فایل از نوع MIME",
    "is" : "هست ",
    "is not" : "نیست",
    "matches" : "مطابق است",
    "does not match" : "مطابق نیست",
    "Example: {placeholder}" : "برای مثال {جای قرار دادن }",
    "File size (upload)" : "حجم فایل (بارگزاری شده )",
    "less" : "کمتر",
    "less or equals" : "کمتر یا مساوی ",
    "greater or equals" : "بزرگتر یا مساوی",
    "greater" : "بزرگتر",
    "File system tag" : "برچسب فایل های سیستمی ",
    "is tagged with" : "برچسب خورده با ",
    "is not tagged with" : "برچسب نخورده با ",
    "Select tag…" : "انتخاب برچسب",
    "Request remote address" : "درخواست آدرس ریموت",
    "matches IPv4" : "مطابق با آی پی ورژن 4",
    "does not match IPv4" : "مطابق نیست با آی پی ورژن 4",
    "matches IPv6" : "مطابق با آی پی ورژن 6 ",
    "does not match IPv6" : "مطابق نیست با آی پی ورژن 6 ",
    "Request time" : "زمان درخواست ",
    "between" : "بین ",
    "not between" : "نیست بین",
    "Start" : "شروع",
    "End" : "پایان ",
    "Select timezone…" : "انتخاب منطقه زمانی ",
    "Request URL" : "درخواست URL",
    "Predefined URLs" : "URL از پیش تعریف شده ",
    "Files WebDAV" : "فایل های WebDAV",
    "Request user agent" : "درخواست سفیر کاربر",
    "Sync clients" : "دستگاه های همگام ",
    "Android client" : "دستگاه های اندروید ",
    "iOS client" : "دستگاه های IOS",
    "Desktop client" : "دستگاه دسکتاپ",
    "User group membership" : "عضویت کاربر در گروه",
    "is member of" : "عضو است در ",
    "is not member of" : "عضو نیست در ",
    "The given operator is invalid" : "اپراتور گرفته شده بی اعتبار است ",
    "The given regular expression is invalid" : "عبارت منظم گرفته شده معتبر نیست ",
    "The given file size is invalid" : "حجم فایل معتبر نیست",
    "The given tag id is invalid" : "آی دی برچسب معتبر نیست ",
    "The given IP range is invalid" : "رنج آی پی گرفته شده معتبر نیست",
    "The given IP range is not valid for IPv4" : "رنج آی پی گرفته شده برای آی پی ورژن 4 معتبر نیست",
    "The given IP range is not valid for IPv6" : "رنج آی پی گرفته شده برای آی پی ورژن 6 معتبر نیست",
    "The given time span is invalid" : "طول تاریخ گرفته شده معتبر نیست ",
    "The given start time is invalid" : "تاریخ شروع معتبر نیست",
    "The given end time is invalid" : "تاریخ پایان معتبر نیست ",
    "The given group does not exist" : "گروه گرفته شده معتبر نیست",
    "Check %s is invalid or does not exist" : "%s یا وجود ندارد یا معتبر نیست",
    "Operation #%s does not exist" : "عمل %s وجود ندارد",
    "Operation %s does not exist" : "عمل %s وجود ندارد ",
    "Operation %s is invalid" : "عمل %s معتبر نیست",
    "Check %s does not exist" : "%s را چک کنید وجود ندارد",
    "Check %s is invalid" : "%s را چک کنید معتبر نیست",
    "Check #%s does not exist" : "%s را چک کنید وجود ندارد ",
    "Workflow" : "جریان کاری",
    "Open documentation" : "مستندات باز",
    "Add rule group" : "اضافه کردن قوانین گروه",
    "Short rule description" : "توضیحات مختصر درباره قوانین ",
    "Add rule" : "اضافه کردن قوانین ",
    "Reset" : "ریست",
    "Save" : "ذخیره",
    "Saving…" : "در حال ذخیره",
    "Loading…" : "در حال بار گزاری"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fa.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "توضیحات مختصر درباره قوانین ",
    "Add rule" : "اضافه کردن قوانین ",
    "Reset" : "ریست",
    "Save" : "ذخیره",
    "Saving…" : "در حال ذخیره",
    "Saved" : "ذخیره شده ",
    "Saving failed:" : "ذخیره فایل با خطا مواجه شد.",
    "Add rule group" : "اضافه کردن قوانین گروه",
    "File MIME type" : "فایل از نوع MIME",
    "is" : "هست ",
    "is not" : "نیست",
    "matches" : "مطابق است",
    "does not match" : "مطابق نیست",
    "Example: {placeholder}" : "برای مثال {جای قرار دادن }",
    "File size (upload)" : "حجم فایل (بارگزاری شده )",
    "less" : "کمتر",
    "less or equals" : "کمتر یا مساوی ",
    "greater or equals" : "بزرگتر یا مساوی",
    "greater" : "بزرگتر",
    "File system tag" : "برچسب فایل های سیستمی ",
    "is tagged with" : "برچسب خورده با ",
    "is not tagged with" : "برچسب نخورده با ",
    "Select tag…" : "انتخاب برچسب",
    "Request remote address" : "درخواست آدرس ریموت",
    "matches IPv4" : "مطابق با آی پی ورژن 4",
    "does not match IPv4" : "مطابق نیست با آی پی ورژن 4",
    "matches IPv6" : "مطابق با آی پی ورژن 6 ",
    "does not match IPv6" : "مطابق نیست با آی پی ورژن 6 ",
    "Request time" : "زمان درخواست ",
    "between" : "بین ",
    "not between" : "نیست بین",
    "Start" : "شروع",
    "End" : "پایان ",
    "Select timezone…" : "انتخاب منطقه زمانی ",
    "Request URL" : "درخواست URL",
    "Predefined URLs" : "URL از پیش تعریف شده ",
    "Files WebDAV" : "فایل های WebDAV",
    "Request user agent" : "درخواست سفیر کاربر",
    "Sync clients" : "دستگاه های همگام ",
    "Android client" : "دستگاه های اندروید ",
    "iOS client" : "دستگاه های IOS",
    "Desktop client" : "دستگاه دسکتاپ",
    "User group membership" : "عضویت کاربر در گروه",
    "is member of" : "عضو است در ",
    "is not member of" : "عضو نیست در ",
    "The given operator is invalid" : "اپراتور گرفته شده بی اعتبار است ",
    "The given regular expression is invalid" : "عبارت منظم گرفته شده معتبر نیست ",
    "The given file size is invalid" : "حجم فایل معتبر نیست",
    "The given tag id is invalid" : "آی دی برچسب معتبر نیست ",
    "The given IP range is invalid" : "رنج آی پی گرفته شده معتبر نیست",
    "The given IP range is not valid for IPv4" : "رنج آی پی گرفته شده برای آی پی ورژن 4 معتبر نیست",
    "The given IP range is not valid for IPv6" : "رنج آی پی گرفته شده برای آی پی ورژن 6 معتبر نیست",
    "The given time span is invalid" : "طول تاریخ گرفته شده معتبر نیست ",
    "The given start time is invalid" : "تاریخ شروع معتبر نیست",
    "The given end time is invalid" : "تاریخ پایان معتبر نیست ",
    "The given group does not exist" : "گروه گرفته شده معتبر نیست",
    "Check %s is invalid or does not exist" : "%s یا وجود ندارد یا معتبر نیست",
    "Operation #%s does not exist" : "عمل %s وجود ندارد",
    "Operation %s does not exist" : "عمل %s وجود ندارد ",
    "Operation %s is invalid" : "عمل %s معتبر نیست",
    "Check %s does not exist" : "%s را چک کنید وجود ندارد",
    "Check %s is invalid" : "%s را چک کنید معتبر نیست",
    "Check #%s does not exist" : "%s را چک کنید وجود ندارد ",
    "Open documentation" : "مستندات باز",
    "Loading…" : "در حال بار گزاری",
    "Workflow" : "جریان کاری"
},
"nplurals=2; plural=(n > 1);");
